@@ -1,10 +1,12 @@
-//$Id: kmagselrect.h,v 1.7 2003/03/06 13:02:41 ojschmidt Exp $
-//==========================================================================
-//
-//   KMagSelRect.h
-//
-//==========================================================================
-
+/***************************************************************************
+                          kmagselrect.h  -  description
+                             -------------------
+    begin                : Mon Feb 12 23:45:41 EST 2001
+    copyright            : (C) 2001-2003 by Sarang Lakare
+    email                : sarang#users.sf.net
+    copyright            : (C) 2003-2004 by Olaf Schmidt
+    email                : ojschmidt@kde.org
+ ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -21,17 +23,74 @@
 #include <stdlib.h>
 
 // Qt includes
-#include <qapplication.h>
 #include <qrect.h>
 #include <qwidget.h>
-#include <qcursor.h>
-
-// X11 includes
-#include <X11/Xlib.h>
+#include <qlabel.h>
 
 // Min function
 #define min(a,b) ((a) < (b) ? (a) : (b))
 
+class KMagSelWinCorner : public QLabel
+{
+    Q_OBJECT
+
+public:
+
+    KMagSelWinCorner ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
+
+    virtual ~KMagSelWinCorner();
+
+signals:
+
+    void startResizing ();
+    void resized ( QPoint offset );
+
+protected:
+
+    QPoint oldPos;
+
+    virtual void mousePressEvent ( QMouseEvent * e );
+    virtual void mouseReleaseEvent ( QMouseEvent * e );
+    virtual void mouseMoveEvent ( QMouseEvent * e );
+};
+
+class KMagSelWin : public QWidget
+{
+    Q_OBJECT
+
+public:
+
+    KMagSelWin ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
+
+    virtual ~KMagSelWin();
+
+    void setSelRect ( QRect selRect );
+    QRect getSelRect ();
+
+public slots:
+
+    void startResizing ();
+    void titleMoved ( QPoint offset );
+    void topLeftResized ( QPoint offset );
+    void topRightResized ( QPoint offset );
+    void bottomLeftResized ( QPoint offset );
+    void bottomRightResized ( QPoint offset );
+
+signals:
+
+    void resized();
+
+protected:
+
+    QRect oldSelRect;
+
+    KMagSelWinCorner *titleBar;
+    KMagSelWinCorner *topLeftCorner;
+    KMagSelWinCorner *topRightCorner;
+    KMagSelWinCorner *bottomLeftCorner;
+    KMagSelWinCorner *bottomRightCorner;
+};
+
 /**
  * This class stores the selected rectangular area for grabbing. It also displays the
  * rectangular area on demand.
@@ -45,12 +104,12 @@ class KMagSelRect : public QObject, public QRect
 
 public:
     KMagSelRect(QWidget *parent=0);
-    KMagSelRect(const QPoint &topleft, const QPoint &bottomright,
+    KMagSelRect(const QPoint &topLeft, const QPoint &bottomRight,
       QWidget *parent=0);
-    KMagSelRect(const QPoint &topleft, const QSize &size,
+    KMagSelRect(const QPoint &topLeft, const QSize &size,
       QWidget *parent=0);
     KMagSelRect(int left, int top, int width, int height,
-      QWidget *parent=0);
+      QWidget *selWindowParent=0);
 
     virtual ~KMagSelRect();
 
@@ -70,21 +129,19 @@ public slots:
     void hide();
     void update();
 
-signals:
-
-    void updated();
+    void selWinResized();
 
 protected:
 
     void init(QWidget *);
-    void paint(const QRect &);
 
-    GC gc;
-    QWidget *parent;
-    bool isVisible;
-    QRect old;
+    QWidget *selWindowParent;
+    KMagSelWin *selectionwindow;
     bool m_alwaysVisible;
 
 };
 
+void setTitleColors (QColor title, QColor text, QColor titleBtn);
+void setFrameSize (int size);
+
 #endif // KMAGSELRECT_H
