@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: phrasebookdialog.cpp,v 1.6 2003/01/31 17:45:14 gunnar Exp $
-
 // include files for QT
 #include <qapplication.h>
 #include <qlayout.h>
@@ -29,6 +27,7 @@
 #include <qpopupmenu.h>
 #include <qvaluestack.h>
 #include <qptrstack.h>
+#include <qwhatsthis.h>
 
 // include files for KDE
 #include <kpopupmenu.h>
@@ -214,7 +213,7 @@ void InitialPhraseBookWidget::createBook () {
       else {
          if (((QCheckListItem*)item)->isOn()) {
             PhraseBook localBook;
-            localBook.open(item->text(PhraseBookPrivate::filename));
+            localBook.open(KURL( item->text(PhraseBookPrivate::filename )));
             book += localBook;
          }
          
@@ -228,7 +227,7 @@ void InitialPhraseBookWidget::createBook () {
 
    QString bookLocation = KApplication::kApplication()->dirs()->saveLocation ("appdata", "/");
    if (!bookLocation.isNull() && !bookLocation.isEmpty()) {
-      book.save (bookLocation + "standard.phrasebook");
+      book.save (KURL( bookLocation + "standard.phrasebook" ));
    }
 }
 
@@ -240,6 +239,7 @@ ButtonBoxWidget::ButtonBoxWidget (QWidget *parent, const char *name)
 
    keyButton = new KKeyButton (keyButtonPlace, "key");
    keyButtonPlaceLayout->addWidget (keyButton, 1,1);
+   QWhatsThis::add (keyButton, i18n("By clicking on this button you can select the keyboard shortcut associated with the selected phrase."));
 
    group = new QButtonGroup (phrasebox);
    group->hide();
@@ -267,14 +267,14 @@ PhraseBookDialog::PhraseBookDialog ()
    QString standardBook = KApplication::kApplication()->dirs()->findResource("appdata", "standard.phrasebook");
    if (!standardBook.isNull() && !standardBook.isEmpty()) {
       PhraseBook book;
-      book.open(standardBook);
+      book.open(KURL( standardBook ));
       treeView->clear();
       treeView->addBook(0, 0, &book);
       treeView->setCurrentItem(treeView->firstChild());
-      currentChanged(treeView->currentItem());
+      selectionChanged();
       phrasebookChanged = false;
    }
-   // i18n("Edit phrase book")
+   // i18n("Edit Phrase Book")
 }
 
 PhraseBookDialog *PhraseBookDialog::get() {
@@ -302,7 +302,8 @@ void PhraseBookDialog::initGUI () {
    treeView->setRootIsDecorated (true);
    treeView->setAllColumnsShowFocus (true);
    treeView->setSelectionMode (QListView::Extended); 
-   connect (treeView, SIGNAL(currentChanged(QListViewItem *)), this, SLOT(currentChanged(QListViewItem *)));
+   QWhatsThis::add (treeView, i18n("This list contains the current phrase book in a tree structure. You can select and modify individual phrases and sub phrase books"));
+   connect (treeView, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
    connect (treeView, SIGNAL(contextMenuRequested (QListViewItem *, const QPoint &, int)), this, SLOT(contextMenuRequested (QListViewItem *, const QPoint &, int)));
    connect (treeView, SIGNAL(dropped (QDropEvent *, QListViewItem *, QListViewItem *)), this, SLOT(slotDropped (QDropEvent *, QListViewItem *, QListViewItem *)));
    connect (treeView, SIGNAL(moved (QListViewItem *, QListViewItem *, QListViewItem *)), this, SLOT(slotMoved (QListViewItem *, QListViewItem *, QListViewItem *)));
@@ -316,7 +317,7 @@ void PhraseBookDialog::initGUI () {
    mainLayout->addWidget (buttonBox);
 
    treeView->setFocus();
-   currentChanged(0);
+   selectionChanged();
 }
 
 void PhraseBookDialog::initActions() {
@@ -341,7 +342,7 @@ void PhraseBookDialog::initActions() {
    toolbarImport->setStatusText(i18n("Imports a file and adds its contents to the phrase book"));
    toolbarImport->setWhatsThis (i18n("Imports a file and adds its contents to the phrase book"));
 
-   fileImportStandardBook = new KActionMenu (i18n("Import &Standard Phrase Book"), "phrasebook_open", actionCollection(),"file_import_standard_book");
+   fileImportStandardBook = new KActionMenu (i18n("I&mport Standard Phrase Book"), "phrasebook_open", actionCollection(),"file_import_standard_book");
    fileImportStandardBook->setStatusText(i18n("Imports a standard phrase book and adds its contents to the phrase book"));
    fileImportStandardBook->setWhatsThis (i18n("Imports a standard phrase book and adds its contents to the phrase book"));
 
@@ -409,7 +410,7 @@ StandardBookList PhraseBookDialog::standardPhraseBooks() {
    QStringList::iterator it;
    for (it = bookPaths.begin(); it != bookPaths.end(); ++it) {
       PhraseBook pbook;
-      if (pbook.open (*it)) {
+      if (pbook.open (KURL( *it ))) {
          StandardBook book;
          book.name = (*pbook.begin()).getPhrase().getPhrase();
          
@@ -461,17 +462,31 @@ void PhraseBookDialog::initStandardPhraseBooks () {
       currentNamePath = dirs;
       
       KAction *book = new StandardPhraseBookInsertAction (
-          url, (*it).path+"/"+(*it).name, (*it).name,
-          this, SLOT(slotImportPhrasebook (const KURL &, const QString &)), 0);
+          url, (*it).name, this, SLOT(slotImportPhrasebook (const KURL &)), actionCollection());
       parent->insert(book);
       if (parent == fileImportStandardBook)
          book->plug(toolbarImport->popupMenu());
    }
 }
 
-void PhraseBookDialog::currentChanged (QListViewItem *item) {
+PhraseTreeItem *selectedItem (QListView *treeView) {
+   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
+   if ((currentItem == 0) || (!currentItem->isSelected()))
+      return 0;
+
+   QListViewItemIterator it(treeView);
+   while (it.current()) {
+      QListViewItem *item = it.current();
+      if (item->isSelected() && (item != currentItem))
+         return 0;
+      ++it;
+   }
+   return currentItem;
+}
+
+void PhraseBookDialog::selectionChanged () {
    bool modified = phrasebookChanged;
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)item;
+   PhraseTreeItem *currentItem = selectedItem (treeView);
    if (currentItem == 0) {
       buttonBox->textLabel->setText (i18n("Text of the &phrase:"));
       buttonBox->textLabel->setEnabled(false);
@@ -526,11 +541,10 @@ void PhraseBookDialog::currentChanged (QListViewItem *item) {
 
 bool PhraseBookDialog::queryClose() {
    if (phrasebookChanged) {
-      KGuiItem no = KGuiItem (i18n("Do &not save"));
       int answer = KMessageBox::questionYesNoCancel (this,
-          i18n("Do you want to save the changes of the phrase book?"),
-          i18n("Closing the \"Phrase book\" window"),
-          KStdGuiItem::yes(), no, "AutomaticSave");
+          i18n("There are unsaved changes.<br>Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?"),
+          i18n("Closing \"Phrase Book\" Window"),
+          KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
       if (answer == KMessageBox::Yes) {
          slotSave();
          return true;
@@ -541,8 +555,8 @@ bool PhraseBookDialog::queryClose() {
 }
 
 void PhraseBookDialog::slotTextChanged (const QString &s) {
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
-   if (currentItem != 0 && currentItem->isSelected())
+   PhraseTreeItem *currentItem = selectedItem (treeView);
+   if (currentItem != 0)
       currentItem->setText(0, s);
    phrasebookChanged = true;
 }
@@ -551,8 +565,8 @@ void PhraseBookDialog::slotNoKey() {
    buttonBox->noKey->setChecked (true);
    buttonBox->customKey->setChecked (false);
    
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
-   if (currentItem != 0 && currentItem->isSelected()) {
+   PhraseTreeItem *currentItem = selectedItem (treeView);
+   if (currentItem != 0) {
       currentItem->setCut (KShortcut(QString::null));
       buttonBox->keyButton->setShortcut(currentItem->cut());
    }
@@ -589,7 +603,7 @@ void PhraseBookDialog::setShortcut( const KShortcut& cut ) {
       }
    }
 
-   PhraseTreeItem *currentItem = (PhraseTreeItem *)treeView->currentItem();
+   PhraseTreeItem *currentItem = selectedItem (treeView);
    // If key isn't already in use,
    if (!treeView->isKeyPresent (cut, currentItem, true)) {
       // Set new key code
@@ -604,7 +618,9 @@ void PhraseBookDialog::setShortcut( const KShortcut& cut ) {
 QListViewItem *PhraseBookDialog::addBook (QListViewItem *parent, QListViewItem *after, PhraseBook *book) {
    QListViewItem *newItem = treeView->addBook(parent, after, book);
    if (newItem != 0) {
+      treeView->clearSelection();
       treeView->ensureItemVisible(newItem);
+      treeView->setCurrentItem (newItem);
       treeView->setSelected (newItem, true);
       phrasebookChanged = true;
    }
@@ -639,6 +655,7 @@ void PhraseBookDialog::contextMenuRequested(QListViewItem *, const QPoint &pos,
 void PhraseBookDialog::slotRemove () {
    if (treeView->hasSelectedItems() != 0)
       treeView->deleteSelectedItems();
+   selectionChanged();
    phrasebookChanged = true;
 }
 
@@ -705,10 +722,10 @@ void PhraseBookDialog::slotImportPhrasebook () {
    KURL url=KFileDialog::getOpenURL(QString::null,
         i18n("*.phrasebook|Phrase Books (*.phrasebook)\n*.txt|Plain Text Files (*.txt)\n*|All Files"), this, i18n("Import Phrasebook"));
 
-   slotImportPhrasebook (url, QString::null);
+   slotImportPhrasebook (url);
 }
 
-void PhraseBookDialog::slotImportPhrasebook (const KURL &url, const QString &path) {
+void PhraseBookDialog::slotImportPhrasebook (const KURL &url) {
    if(!url.isEmpty()) {
       PhraseBook book;
       if (book.open (url))
@@ -723,7 +740,7 @@ void PhraseBookDialog::slotExportPhrasebook () {
    treeView->fillBook (&book, treeView->hasSelectedItems());
    
    KURL url;
-   if (book.save (this, i18n("Export Phrase Book"), url) == -1);
+   if (book.save (this, i18n("Export Phrase Book"), url) == -1)
       KMessageBox::sorry(this,i18n("There was an error saving file\n%1").arg( url.url() ));
 }
 
@@ -739,118 +756,3 @@ void PhraseBookDialog::slotPrint()
 }
 
 #include "phrasebookdialog.moc"
-
-/*
- * $Log: phrasebookdialog.cpp,v $
- * Revision 1.6  2003/01/31 17:45:14  gunnar
- * Added kttsd (Proklam) support and some small changes
- *
- * Revision 1.5  2003/01/19 21:42:58  gunnar
- * Eliminated need for a .desktop file for each standard phrase book file
- *
- * Revision 1.4  2003/01/18 18:25:34  gunnar
- * Renamed .stdbook files to .desktop files and added extended versions of the standard phrasebooks
- *
- * Revision 1.3  2003/01/18 15:47:46  gunnar
- * Two small changes
- *
- * Revision 1.2  2003/01/18 07:29:12  binner
- * CVS_SILENT i18n style guide fixes
- *
- * Revision 1.1  2003/01/17 23:09:36  gunnar
- * Imported KMouth into kdeaccessibility
- *
- * Revision 1.20  2003/01/13 09:18:07  gunnar
- * Import of standard phrase books improved.
- *
- * Revision 1.19  2003/01/12 20:26:02  gunnar
- * Printing phrase book added
- *
- * Revision 1.18  2003/01/12 11:37:05  gunnar
- * Improved format list of file selectors / several small changes
- *
- * Revision 1.17  2003/01/08 16:58:40  gunnar
- * Selection of multiple phrase book entres in the editor added
- *
- * Revision 1.16  2002/12/30 11:45:29  gunnar
- * Wizard page for initial phrase book improved
- *
- * Revision 1.15  2002/12/29 12:10:38  gunnar
- * Wizard page for initial phrase book improved
- *
- * Revision 1.14  2002/12/06 08:55:05  gunnar
- * Improved the algorithm for creating the initial phrasebook
- *
- * Revision 1.13  2002/12/04 16:22:02  gunnar
- * Include *.moc files
- *
- * Revision 1.12  2002/11/25 16:24:53  gunnar
- * Changes on the way to version 0.7.99.1rc1
- *
- * Revision 1.11  2002/11/22 14:51:39  gunnar
- * Wizard for first start extended
- *
- * Revision 1.10  2002/11/22 09:29:11  gunnar
- * Small changes
- *
- * Revision 1.9  2002/11/22 08:48:34  gunnar
- * Implemented functionality that belongs to the new options in the options dialog
- *
- * Revision 1.8  2002/11/21 21:33:27  gunnar
- * Extended parameter dialog and added wizard for the first start
- *
- * Revision 1.7  2002/11/20 10:55:44  gunnar
- * Improved the keyboard accessibility
- *
- * Revision 1.6  2002/11/19 19:45:06  gunnar
- * Added "Do you want to save?"-question to the phrase book edit window
- *
- * Revision 1.5  2002/11/19 19:11:28  gunnar
- * Extended the tool bar of the phrase book edit window
- *
- * Revision 1.4  2002/11/19 17:48:14  gunnar
- * Prevented both the parallel start of multiple KMouth instances and the parallel opening of multiple Phrase book edit windows
- *
- * Revision 1.3  2002/11/17 17:13:18  gunnar
- * Several small changes in the phrase book edit window
- *
- * Revision 1.2  2002/11/14 21:19:57  gunnar
- * Extended the menu bar of the phrase book dialog
- *
- * Revision 1.1  2002/11/11 21:25:44  gunnar
- * Moved the parts concerning phrase books into a static library
- *
- * Revision 1.11  2002/11/06 19:15:08  gunnar
- * import of standard phrase books added
- *
- * Revision 1.10  2002/11/06 17:28:02  gunnar
- * Code for preventing double keyboard shortcuts extended for imported/dragged/pasted phrasebooks
- *
- * Revision 1.9  2002/11/04 21:13:08  gunnar
- * added code to prevent double shortcuts
- *
- * Revision 1.8  2002/10/29 16:16:06  gunnar
- * Connection from the phrase book to the phrase edit field added
- *
- * Revision 1.7  2002/10/28 16:58:34  gunnar
- * Import and export of phrase books implemented
- *
- * Revision 1.6  2002/10/24 19:36:29  gunnar
- * Drag and drop support in the phrase book edit dialog improved
- *
- * Revision 1.5  2002/10/23 22:19:30  gunnar
- * Cut, copy and paste features of the phrase book edit dialog improved
- *
- * Revision 1.4  2002/10/23 17:42:53  gunnar
- * Icons added to the items of the phrase book edit dialog
- *
- * Revision 1.3  2002/10/22 20:10:29  gunnar
- * Cut and copy of phrase book entries implemented
- *
- * Revision 1.2  2002/10/22 16:13:24  gunnar
- * Popup menu in the phrase book dialog added
- *
- * Revision 1.1  2002/10/21 18:30:50  gunnar
- * First version of the phrase book edit dialog added
- *
- */
